#! /bin/sh
# \
	exec wish $0 ${1+"$@"}


#----------------------------------------------------------------------
# Preamble: Find and load the eclipse package
#----------------------------------------------------------------------

switch $tcl_platform(platform) {
    unix {
	if {![info exists env(ECLIPSEDIR)]} {
	    puts "Cannot run Eclipse: ECLIPSEDIR environment variable is undefined."
	    exit -1
	}
	set tkecl(ECLIPSEDIR) $env(ECLIPSEDIR)
    }
    windows {
	package require registry
	set tkecl(ECLIPSEDIR) [registry get \
	    HKEY_LOCAL_MACHINE\\SOFTWARE\\IC-Parc\\Eclipse\\7.0 ECLIPSEDIR]
    }
    default {
	error "$tcl_platform(platform) not supported"
	exit -1
    }
}

lappend auto_path [file join $tkecl(ECLIPSEDIR) lib_tcl]

package require eclipse
package require eclipse_tools


#----------------------------------------------------------------------
# Make a standard menu bar and a 'File' and 'Tools' menu
#----------------------------------------------------------------------

wm title . "A small ECLiPSe/Tcl/Tk Application"

. config -menu .mbar

menu .mbar
.mbar add cascade -label File -menu .mbar.file
.mbar add cascade -label Tools -menu .mbar.tools

menu .mbar.file
.mbar.file add command -label Exit -command exit


#----------------------------------------------------------------------
# Initialise the embedded ECLiPSe (plus the optional toolkit)
#----------------------------------------------------------------------

#ec_set_option io 0;	# uncomment this to debug bootstrapping problems

ec_init
ec_tools_init .mbar.tools


#----------------------------------------------------------------------
# Create some input widgets
#----------------------------------------------------------------------

button .button2 -text Double -command "set buttonpressed double"
pack .button2 -side top -expand true -fill x
button .button3 -text Triple -command "set buttonpressed triple"
pack .button3 -side top -expand true -fill x
button .button4 -text Quadruple -command "set buttonpressed quadruple"
pack .button4 -side top -expand true -fill x


#----------------------------------------------------------------------
# Add an output window and connect it to the eclipse 'output' stream
# (this makes writeln/1 etc go to that window instead of a popup)
#----------------------------------------------------------------------

text .tout
pack .tout

ec_queue_connect output r {ec_stream_to_window {} .tout}


#----------------------------------------------------------------------
# Create two queues for communication, and a handler
#----------------------------------------------------------------------

ec_queue_create result_from_ecl fromec handle_result
ec_queue_create command_from_tcl toec

proc handle_result {stream} {
    global buttonpressed
    
    set result [ec_read_exdr [ec_streamnum_to_channel $stream]]
    .tout insert end "Received result: $result\n"

    vwait buttonpressed
    ec_write_exdr [ec_streamname_to_channel command_from_tcl] $buttonpressed ()
    ec_flush [ec_streamname_to_streamnum command_from_tcl]

}


#----------------------------------------------------------------------
# Compile ECLiPSe part and start main predicate
#----------------------------------------------------------------------

ec_rpc [list compile example_queues1] (())

set data {3 6 9 12 15}

ec_rpc [list main $data] {([I*])}

